@@ -37,7 +37,6 @@ class DocumentRoom(YRoom):
         self._room_id: str = room_id
         self._file_format: str = file_format
         self._file_type: str = file_type
-        self._last_modified: Any = None
         self._file: FileLoader = file
         self._document = YDOCS.get(self._file_type, YFILE)(self.ydoc)
 
@@ -52,7 +51,7 @@ class DocumentRoom(YRoom):
 
         # Listen for document changes
         self._document.observe(self._on_document_change)
-        self._file.observe(self.room_id, self._on_content_change)
+        self._file.observe(self.room_id, self._on_outofband_change)
 
     @property
     def room_id(self) -> str:
@@ -96,7 +95,7 @@ class DocumentRoom(YRoom):
 
             self.log.info("Initializing room %s", self._room_id)
 
-            model = await self._file.load_content(self._file_format, self._file_type, True)
+            model = await self._file.load_content(self._file_format, self._file_type)
 
             async with self._update_lock:
                 # try to apply Y updates from the YStore for this document
@@ -145,7 +144,6 @@ class DocumentRoom(YRoom):
                     if self.ystore:
                         await self.ystore.encode_state_as_update(self.ydoc)
 
-                self._last_modified = model["last_modified"]
                 self._document.dirty = False
                 self.ready = True
                 self._emit(LogLevel.INFO, "initialize", "Room initialized")
@@ -180,32 +178,24 @@ class DocumentRoom(YRoom):
         except asyncio.CancelledError:
             pass
 
-    async def _on_content_change(self, event: str, args: dict[str, Any]) -> None:
+    async def _on_outofband_change(self) -> None:
         """
-        Called when the file changes.
-
-            Parameters:
-                event (str): Type of change.
-                args (dict): A dictionary with format, type, last_modified.
+        Called when the file got out-of-band changes.
         """
-        if event == "metadata" and (
-            self._last_modified is None or self._last_modified < args["last_modified"]
-        ):
-            self.log.info("Out-of-band changes. Overwriting the content in room %s", self._room_id)
-            self._emit(LogLevel.INFO, "overwrite", "Out-of-band changes. Overwriting the room.")
+        self.log.info("Out-of-band changes. Overwriting the content in room %s", self._room_id)
+        self._emit(LogLevel.INFO, "overwrite", "Out-of-band changes. Overwriting the room.")
 
-            try:
-                model = await self._file.load_content(self._file_format, self._file_type, True)
-            except Exception as e:
-                msg = f"Error loading content from file: {self._file.path}\n{e!r}"
-                self.log.error(msg, exc_info=e)
-                self._emit(LogLevel.ERROR, None, msg)
-                return None
+        try:
+            model = await self._file.load_content(self._file_format, self._file_type)
+        except Exception as e:
+            msg = f"Error loading content from file: {self._file.path}\n{e!r}"
+            self.log.error(msg, exc_info=e)
+            self._emit(LogLevel.ERROR, None, msg)
+            return
 
-            async with self._update_lock:
-                self._document.source = model["content"]
-                self._last_modified = model["last_modified"]
-                self._document.dirty = False
+        async with self._update_lock:
+            self._document.source = model["content"]
+            self._document.dirty = False
 
     def _on_document_change(self, target: str, event: Any) -> None:
         """
@@ -225,14 +215,11 @@ class DocumentRoom(YRoom):
         if self._update_lock.locked():
             return
 
-        if self._saving_document is not None and not self._saving_document.done():
-            # the document is being saved, cancel that
-            self._saving_document.cancel()
-            self._saving_document = None
+        self._saving_document = asyncio.create_task(
+            self._maybe_save_document(self._saving_document)
+        )
 
-        self._saving_document = asyncio.create_task(self._maybe_save_document())
-
-    async def _maybe_save_document(self) -> None:
+    async def _maybe_save_document(self, saving_document: asyncio.Task | None) -> None:
         """
         Saves the content of the document to disk.
 
@@ -244,20 +231,23 @@ class DocumentRoom(YRoom):
         if self._save_delay is None:
             return
 
+        if saving_document is not None and not saving_document.done():
+            # the document is being saved, cancel that
+            saving_document.cancel()
+            await saving_document
+
         # save after X seconds of inactivity
         await asyncio.sleep(self._save_delay)
 
         try:
             self.log.info("Saving the content from room %s", self._room_id)
-            model = await self._file.maybe_save_content(
+            await self._file.maybe_save_content(
                 {
                     "format": self._file_format,
                     "type": self._file_type,
-                    "last_modified": self._last_modified,
                     "content": self._document.source,
                 }
             )
-            self._last_modified = model["last_modified"]
             async with self._update_lock:
                 self._document.dirty = False
 
@@ -266,7 +256,7 @@ class DocumentRoom(YRoom):
         except OutOfBandChanges:
             self.log.info("Out-of-band changes. Overwriting the content in room %s", self._room_id)
             try:
-                model = await self._file.load_content(self._file_format, self._file_type, True)
+                model = await self._file.load_content(self._file_format, self._file_type)
             except Exception as e:
                 msg = f"Error loading content from file: {self._file.path}\n{e!r}"
                 self.log.error(msg, exc_info=e)
@@ -275,7 +265,6 @@ class DocumentRoom(YRoom):
 
             async with self._update_lock:
                 self._document.source = model["content"]
-                self._last_modified = model["last_modified"]
                 self._document.dirty = False
 
             self._emit(LogLevel.INFO, "overwrite", "Out-of-band changes while saving.")
